Class: Aws::NotificationsContacts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NotificationsContacts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-notificationscontacts/client.rb,
sig/client.rbs
Overview
An API client for NotificationsContacts. To construct a client, you need to configure a :region and :credentials.
client = Aws::NotificationsContacts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _ActivateEmailContactResponseSuccess, _CreateEmailContactResponseSuccess, _DeleteEmailContactResponseSuccess, _GetEmailContactResponseSuccess, _ListEmailContactsResponseSuccess, _ListTagsForResourceResponseSuccess, _SendActivationCodeResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#activate_email_contact(params = {}) ⇒ Struct
Activates an email contact using an activation code.
-
#create_email_contact(params = {}) ⇒ Types::CreateEmailContactResponse
Creates an email contact for the provided email address.
-
#delete_email_contact(params = {}) ⇒ Struct
Deletes an email contact.
-
#get_email_contact(params = {}) ⇒ Types::GetEmailContactResponse
Returns an email contact.
-
#list_email_contacts(params = {}) ⇒ Types::ListEmailContactsResponse
Lists all email contacts created under the Account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify.
-
#send_activation_code(params = {}) ⇒ Struct
Sends an activation email to the email address associated with the specified email contact.
-
#tag_resource(params = {}) ⇒ Struct
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN).
-
#untag_resource(params = {}) ⇒ Struct
Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN).
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
815 816 817 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 815 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
818 819 820 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 818 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#activate_email_contact(params = {}) ⇒ Struct
Activates an email contact using an activation code. This code is in the activation email sent to the email address associated with this email contact.
85 |
# File 'sig/client.rbs', line 85
def activate_email_contact: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 788 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::NotificationsContacts') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-notificationscontacts' context[:gem_version] = '1.22.0' Seahorse::Client::Request.new(handlers, context) end |
#create_email_contact(params = {}) ⇒ Types::CreateEmailContactResponse
Creates an email contact for the provided email address.
96 |
# File 'sig/client.rbs', line 96
def create_email_contact: (
|
#delete_email_contact(params = {}) ⇒ Struct
Deletes an email contact.
107 |
# File 'sig/client.rbs', line 107
def delete_email_contact: (
|
#get_email_contact(params = {}) ⇒ Types::GetEmailContactResponse
Returns an email contact.
117 |
# File 'sig/client.rbs', line 117
def get_email_contact: (
|
#list_email_contacts(params = {}) ⇒ Types::ListEmailContactsResponse
Lists all email contacts created under the Account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
128 |
# File 'sig/client.rbs', line 128
def list_email_contacts: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The resource can be a user, server, or role.
139 |
# File 'sig/client.rbs', line 139
def list_tags_for_resource: (
|
#send_activation_code(params = {}) ⇒ Struct
Sends an activation email to the email address associated with the specified email contact.
148 |
# File 'sig/client.rbs', line 148
def send_activation_code: (
|
#tag_resource(params = {}) ⇒ Struct
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Taggable resources in AWS User Notifications Contacts include email contacts.
157 |
# File 'sig/client.rbs', line 157
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Taggable resources in AWS User Notifications Contacts include email contacts..
167 |
# File 'sig/client.rbs', line 167
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
808 809 810 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 808 def waiter_names [] end |