Class: Aws::NotificationsContacts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NotificationsContacts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-notificationscontacts/client.rb
Overview
An API client for NotificationsContacts. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::NotificationsContacts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#activate_email_contact(params = {}) ⇒ Struct
Activates an email contact using an activation code.
-
#create_email_contact(params = {}) ⇒ Types::CreateEmailContactResponse
Creates an email contact for the provided email address.
-
#delete_email_contact(params = {}) ⇒ Struct
Deletes an email contact.
-
#get_email_contact(params = {}) ⇒ Types::GetEmailContactResponse
Returns an email contact.
-
#list_email_contacts(params = {}) ⇒ Types::ListEmailContactsResponse
Lists all email contacts created under the Account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify.
-
#send_activation_code(params = {}) ⇒ Struct
Sends an activation email to the email address associated with the specified email contact.
-
#tag_resource(params = {}) ⇒ Struct
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN).
-
#untag_resource(params = {}) ⇒ Struct
Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN).
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
815 816 817 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 815 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
818 819 820 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 818 def errors_module Errors end |
Instance Method Details
#activate_email_contact(params = {}) ⇒ Struct
Activates an email contact using an activation code. This code is in the activation email sent to the email address associated with this email contact.
508 509 510 511 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 508 def activate_email_contact(params = {}, = {}) req = build_request(:activate_email_contact, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 788 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::NotificationsContacts') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-notificationscontacts' context[:gem_version] = '1.20.0' Seahorse::Client::Request.new(handlers, context) end |
#create_email_contact(params = {}) ⇒ Types::CreateEmailContactResponse
Creates an email contact for the provided email address.
552 553 554 555 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 552 def create_email_contact(params = {}, = {}) req = build_request(:create_email_contact, params) req.send_request() end |
#delete_email_contact(params = {}) ⇒ Struct
Deletes an email contact.
<note markdown=“1”> Deleting an email contact removes it from all associated notification configurations.
</note>
579 580 581 582 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 579 def delete_email_contact(params = {}, = {}) req = build_request(:delete_email_contact, params) req.send_request() end |
#get_email_contact(params = {}) ⇒ Types::GetEmailContactResponse
Returns an email contact.
612 613 614 615 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 612 def get_email_contact(params = {}, = {}) req = build_request(:get_email_contact, params) req.send_request() end |
#list_email_contacts(params = {}) ⇒ Types::ListEmailContactsResponse
Lists all email contacts created under the Account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
659 660 661 662 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 659 def list_email_contacts(params = {}, = {}) req = build_request(:list_email_contacts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The resource can be a user, server, or role.
689 690 691 692 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 689 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#send_activation_code(params = {}) ⇒ Struct
Sends an activation email to the email address associated with the specified email contact.
<note markdown=“1”> It might take a few minutes for the activation email to arrive. If it doesn’t arrive, check in your spam folder or try sending another activation email.
</note>
718 719 720 721 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 718 def send_activation_code(params = {}, = {}) req = build_request(:send_activation_code, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Attaches a key-value pair to a resource, as identified by its Amazon Resource Name (ARN). Taggable resources in AWS User Notifications Contacts include email contacts.
748 749 750 751 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 748 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Detaches a key-value pair from a resource, as identified by its Amazon Resource Name (ARN). Taggable resources in AWS User Notifications Contacts include email contacts..
779 780 781 782 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 779 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
808 809 810 |
# File 'lib/aws-sdk-notificationscontacts/client.rb', line 808 def waiter_names [] end |